@@ -1,3 +1,4 @@
+from myst.connectors.model_connectors.arimax import ARIMAX
 from myst.connectors.model_connectors.elastic_net import ElasticNet
 from myst.connectors.model_connectors.extra_trees_regression import ExtraTreesRegression
 from myst.connectors.model_connectors.lightgbm import LightGBM
@@ -17,5 +18,6 @@ __all__ = [
     "MLPRegression",
     "NGBoost",
     "RandomForestRegression",
+    "ARIMAX",
     "XGBoost",
 ]
