@@ -4,6 +4,8 @@ from uuid import UUID
 
 from myst.connectors.source_connector import SourceConnector
 
+CLEANED_OBSERVATIONS_ID = UUID("cfeb3606-217d-4fd0-9abf-21cd04a8e9e7")
+
 
 @enum.unique
 class Field(str, enum.Enum):
@@ -30,6 +32,5 @@ class Field(str, enum.Enum):
 class CleanedObservations(SourceConnector):
     def __init__(self, latitude: float, longitude: float, fields: List[Field]) -> None:
         super().__init__(
-            uuid=UUID("cfeb3606-217d-4fd0-9abf-21cd04a8e9e7"),
-            parameters=dict(latitude=latitude, longitude=longitude, fields=fields),
+            uuid=CLEANED_OBSERVATIONS_ID, parameters=dict(latitude=latitude, longitude=longitude, fields=fields)
         )
