@@ -4,6 +4,8 @@ from uuid import UUID
 
 from myst.connectors.source_connector import SourceConnector
 
+ENHANCED_FORECAST_ID = UUID("1aeaadec-6912-422a-a4fc-5d6765391c17")
+
 
 @enum.unique
 class Field(str, enum.Enum):
@@ -29,6 +31,5 @@ class Field(str, enum.Enum):
 class EnhancedForecast(SourceConnector):
     def __init__(self, latitude: float, longitude: float, fields: List[Field]) -> None:
         super().__init__(
-            uuid=UUID("1aeaadec-6912-422a-a4fc-5d6765391c17"),
-            parameters=dict(latitude=latitude, longitude=longitude, fields=fields),
+            uuid=ENHANCED_FORECAST_ID, parameters=dict(latitude=latitude, longitude=longitude, fields=fields)
         )
