@@ -4,6 +4,8 @@ from uuid import UUID
 
 from myst.connectors.source_connector import SourceConnector
 
+HISTORICAL_HOURLY_CONDITIONS_ID = UUID("6f2851e1-7612-4276-a864-172d8c1a060c")
+
 
 @enum.unique
 class Field(str, enum.Enum):
@@ -41,6 +43,5 @@ class Field(str, enum.Enum):
 class HistoricalHourlyConditions(SourceConnector):
     def __init__(self, latitude: float, longitude: float, fields: List[Field]) -> None:
         super().__init__(
-            uuid=UUID("6f2851e1-7612-4276-a864-172d8c1a060c"),
-            parameters=dict(latitude=latitude, longitude=longitude, fields=fields),
+            uuid=HISTORICAL_HOURLY_CONDITIONS_ID, parameters=dict(latitude=latitude, longitude=longitude, fields=fields)
         )
