@@ -1,7 +1,6 @@
 from myst.client import Client
-
-from ...models.organization_get import OrganizationGet
-from ...models.organization_update import OrganizationUpdate
+from myst.openapi.models.organization_get import OrganizationGet
+from myst.openapi.models.organization_update import OrganizationUpdate
 
 
 def request_sync(client: Client, uuid: str, json_body: OrganizationUpdate) -> OrganizationGet:
