@@ -1,14 +1,21 @@
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 
 from myst.client import Client
 from myst.openapi.models.hpo_result_list import HPOResultList
 
 
-def request_sync(client: Client, project_uuid: str, hpo_uuid: str, job_uuid: str) -> HPOResultList:
+def request_sync(
+    client: Client,
+    project_uuid: str,
+    hpo_uuid: str,
+    job_uuid: str,
+    include_backtest_result_urls: Optional[bool] = False,
+) -> HPOResultList:
     """Filters for HPO results associated with a specific job."""
 
     params: Dict[str, Any] = {}
     params["job_uuid"] = job_uuid
+    params["include_backtest_result_urls"] = include_backtest_result_urls
 
     params = {k: v for k, v in params.items() if v is not None}
 
