@@ -3,7 +3,7 @@ from myst.openapi.models.model_fit_result_get import ModelFitResultGet
 
 
 def request_sync(client: Client, project_uuid: str, model_uuid: str, uuid: str) -> ModelFitResultGet:
-    """Gets a model fit result by its unique identifier."""
+    """Gets the model fit result associated with the given identifier."""
 
     return client.request(
         method="get",
