@@ -3,7 +3,7 @@ from myst.openapi.models.node_run_job_get import NodeRunJobGet
 
 
 def request_sync(client: Client, project_uuid: str, time_series_uuid: str, uuid: str) -> NodeRunJobGet:
-    """Get a run job for time series."""
+    """Gets a time series run job by its unique identifier."""
 
     return client.request(
         method="get",
