@@ -4,7 +4,7 @@ from myst.openapi.models.node_run_job_get import NodeRunJobGet
 
 
 def request_sync(client: Client, project_uuid: str, uuid: str, json_body: NodeJobCreate) -> NodeRunJobGet:
-    """Create ad-hoc run job for time series."""
+    """Create an ad hoc run job for a time series."""
 
     return client.request(
         method="post",
