@@ -8,7 +8,7 @@ from myst.openapi.models.backtest_result_get_metrics import BacktestResultGetMet
 
 
 class BacktestResultGet(base_model.BaseModel):
-    """Schema for model fit result get responses."""
+    """Schema for backtest result get responses."""
 
     object_: Literal["BacktestResult"] = Field(..., alias="object")
     uuid: str
