@@ -1,9 +1,10 @@
-from typing import Any, Dict, Optional
+from typing import Optional
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
+from myst.openapi.models.connector_get_parameters_schema import ConnectorGetParametersSchema
 from myst.openapi.models.connector_get_type import ConnectorGetType
 
 
@@ -16,5 +17,5 @@ class ConnectorGet(base_model.BaseModel):
     title: str
     provider: str
     description: str
-    parameters_schema: Dict[str, Any]
+    parameters_schema: ConnectorGetParametersSchema
     icon_url: Optional[str] = None
