@@ -1,4 +1,4 @@
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 
 from myst.models import base_model
 
@@ -6,7 +6,7 @@ from myst.models import base_model
 class HPOTrialMetrics(base_model.BaseModel):
     """"""
 
-    __root__: Dict[str, float]
+    __root__: Dict[str, Optional[float]]  # manual intervention required
 
     def __getitem__(self, item: str) -> Any:
         return self.__root__[item]
