@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.model_fit_policy_get import ModelFitPolicyGet
+from myst.openapi.models.model_fit_policy_get import ModelFitPolicyGet
 
 
 class ModelFitPolicyList(base_model.BaseModel):
