@@ -1,10 +1,12 @@
-from typing import Any, Dict, List, Optional
+from typing import List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
 from myst.openapi.models.deploy_status import DeployStatus
+from myst.openapi.models.model_get_input_specs_schema import ModelGetInputSpecsSchema
+from myst.openapi.models.model_get_parameters import ModelGetParameters
 from myst.openapi.models.time_dataset_spec import TimeDatasetSpec
 
 
@@ -22,8 +24,8 @@ class ModelGet(base_model.BaseModel):
     creator: str
     deploy_status: DeployStatus
     connector_uuid: str
-    parameters: Dict[str, Any]
-    input_specs_schema: Dict[str, Any]
+    parameters: ModelGetParameters
+    input_specs_schema: ModelGetInputSpecsSchema
     update_time: Optional[str] = None
     description: Optional[str] = None
     output_specs: Optional[List[TimeDatasetSpec]] = None
