@@ -1,10 +1,12 @@
-from typing import Any, Dict, List, Optional
+from typing import List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
 from myst.openapi.models.deploy_status import DeployStatus
+from myst.openapi.models.model_update_input_specs_schema import ModelUpdateInputSpecsSchema
+from myst.openapi.models.model_update_parameters import ModelUpdateParameters
 from myst.openapi.models.time_dataset_spec import TimeDatasetSpec
 
 
@@ -23,6 +25,6 @@ class ModelUpdate(base_model.BaseModel):
     project: Optional[str] = None
     deploy_status: Optional[DeployStatus] = None
     connector_uuid: Optional[str] = None
-    parameters: Optional[Dict[str, Any]] = None
+    parameters: Optional[ModelUpdateParameters] = None
     output_specs: Optional[List[TimeDatasetSpec]] = None
-    input_specs_schema: Optional[Dict[str, Any]] = None
+    input_specs_schema: Optional[ModelUpdateInputSpecsSchema] = None
