@@ -1,9 +1,10 @@
-from typing import Any, Dict, Optional
+from typing import Optional
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
+from myst.openapi.models.operation_connector_get_parameters_schema import OperationConnectorGetParametersSchema
 
 
 class OperationConnectorGet(base_model.BaseModel):
@@ -15,5 +16,5 @@ class OperationConnectorGet(base_model.BaseModel):
     title: str
     provider: str
     description: str
-    parameters_schema: Dict[str, Any]
+    parameters_schema: OperationConnectorGetParametersSchema
     icon_url: Optional[str] = None
