@@ -1,9 +1,10 @@
-from typing import Any, Dict, Optional
+from typing import Optional
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
+from myst.openapi.models.operation_create_parameters import OperationCreateParameters
 
 
 class OperationCreate(base_model.BaseModel):
@@ -14,4 +15,4 @@ class OperationCreate(base_model.BaseModel):
     object_: Optional[Literal["Node"]] = Field("Node", alias="object")
     type: Optional[Literal["Operation"]] = "Operation"
     description: Optional[str] = None
-    parameters: Optional[Dict[str, Any]] = None
+    parameters: Optional[OperationCreateParameters] = None
