@@ -13,4 +13,4 @@ class RelativeTimingCreate(base_model.BaseModel):
     object_: Optional[Literal["Timing"]] = Field("Timing", alias="object")
     frequency: Optional[str] = None
     offset: Optional[str] = None
-    time_zone: Optional[str] = "UTC"
+    time_zone: Optional[str] = None
