@@ -1,10 +1,11 @@
-from typing import Any, Dict, List, Optional
+from typing import List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
 from myst.openapi.models.deploy_status import DeployStatus
+from myst.openapi.models.source_get_parameters import SourceGetParameters
 from myst.openapi.models.time_dataset_spec import TimeDatasetSpec
 
 
@@ -22,7 +23,7 @@ class SourceGet(base_model.BaseModel):
     creator: str
     deploy_status: DeployStatus
     connector_uuid: str
-    parameters: Dict[str, Any]
+    parameters: SourceGetParameters
     update_time: Optional[str] = None
     description: Optional[str] = None
     output_specs: Optional[List[TimeDatasetSpec]] = None
