@@ -4,8 +4,7 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-
-from ..models.deploy_status import DeployStatus
+from myst.openapi.models.deploy_status import DeployStatus
 
 
 class TimeSeriesUpdate(base_model.BaseModel):
