@@ -1,10 +1,14 @@
 import enum
+import math
 from dataclasses import dataclass
-from typing import Mapping, MutableMapping, Optional, Tuple, Union
-from uuid import UUID
+from typing import Mapping, Optional, Union
 
 from myst.connectors.source_connectors import cleaned_observations, enhanced_forecast, historical_hourly_conditions
+from myst.connectors.source_connectors.cleaned_observations import CLEANED_OBSERVATIONS_ID
+from myst.connectors.source_connectors.enhanced_forecast import ENHANCED_FORECAST_ID
+from myst.connectors.source_connectors.historical_hourly_conditions import HISTORICAL_HOURLY_CONDITIONS_ID
 from myst.core.time.time_delta import TimeDelta
+from myst.models.types import UUIDOrStr
 from myst.recipes.metar_station import MetarStation
 from myst.recipes.time_series_recipe import TimeSeriesRecipe
 from myst.resources.layer import TimeSeriesLayer
@@ -15,6 +19,7 @@ from myst.resources.time_series import TimeSeries
 _HISTORICAL_APIS_CUTOVER_BOUNDARY = TimeDelta("-PT23H")
 _HISTORICAL_TO_FORECAST_CUTOVER_BOUNDARY = TimeDelta("PT1H")
 _THE_WEATHER_COMPANY_DATA_SAMPLE_PERIOD = TimeDelta("PT1H")
+_SOURCE_CONNECTOR_IDS = (CLEANED_OBSERVATIONS_ID, HISTORICAL_HOURLY_CONDITIONS_ID, ENHANCED_FORECAST_ID)
 
 
 @dataclass
@@ -76,16 +81,6 @@ _FIELD_MAPPINGS: Mapping[Field, _TWCFieldTriple] = {
 }
 
 
-@dataclass
-class _SourceCache:
-    cleaned_observations_source: Source
-    historical_hourly_conditions_source: Source
-    enhanced_forecast_source: Source
-
-
-_SOURCE_CACHE: MutableMapping[Tuple[UUID, MetarStation], _SourceCache] = {}
-
-
 class TheWeatherCompany(TimeSeriesRecipe):
     """A recipe for creating time series that stitch together multiple The Weather Company data sources.
 
@@ -101,7 +96,9 @@ class TheWeatherCompany(TimeSeriesRecipe):
         self._field = field
         self._create_intermediate_time_series = create_intermediate_time_series
 
-    def create(self, project: Project, title: Optional[str] = None, description: Optional[str] = None) -> TimeSeries:
+    def create(
+        self, project: Union["Project", UUIDOrStr], title: Optional[str] = None, description: Optional[str] = None
+    ) -> TimeSeries:
         """Creates a new time series in the given project containing weather data for this recipe.
 
         This method will create the following resources in the given project:
@@ -131,15 +128,31 @@ class TheWeatherCompany(TimeSeriesRecipe):
         Returns:
             the created time series
         """
+        if not isinstance(project, Project):
+            project = Project.get(project)
+
         latitude = self._metar_station.latitude
         longitude = self._metar_station.longitude
 
-        # Cache/look up sources by project + METAR station. This allows low-effort reuse of TWC sources within a single
-        # client process.
-        source_cache_key = (project.uuid, self._metar_station)
+        # List any previously created TWC source nodes for `self._metar_station`.
+        nodes = project.list_nodes()
+        source_connector_nodes_by_connector_id = dict()
+        for node in nodes:
+            if (
+                # The node must be a source node.
+                isinstance(node, Source)
+                # The node must be a TWC source node.
+                and node.connector_uuid in _SOURCE_CONNECTOR_IDS
+                # The node must use the correct latitude and longitude coordinates.
+                and math.isclose(latitude, node.parameters["latitude"])
+                and math.isclose(longitude, node.parameters["longitude"])
+            ):
+                source_connector_nodes_by_connector_id[node.connector_uuid] = node
 
-        # Create the three sources.
-        if source_cache_key not in _SOURCE_CACHE:
+        # Create the cleaned observations source, if it does not exist.
+        if CLEANED_OBSERVATIONS_ID in source_connector_nodes_by_connector_id:
+            cleaned_observations_source = source_connector_nodes_by_connector_id[CLEANED_OBSERVATIONS_ID]
+        else:
             cleaned_observations_fields = [
                 field_triple.cleaned_observations_field for field_triple in _FIELD_MAPPINGS.values()
             ]
@@ -151,6 +164,12 @@ class TheWeatherCompany(TimeSeriesRecipe):
                 ),
             )
 
+        # Create the historical hourly conditions source, if it does not exist.
+        if HISTORICAL_HOURLY_CONDITIONS_ID in source_connector_nodes_by_connector_id:
+            historical_hourly_conditions_source = source_connector_nodes_by_connector_id[
+                HISTORICAL_HOURLY_CONDITIONS_ID
+            ]
+        else:
             historical_hourly_conditions_fields = [
                 field_triple.historical_hourly_conditions_field for field_triple in _FIELD_MAPPINGS.values()
             ]
@@ -162,6 +181,10 @@ class TheWeatherCompany(TimeSeriesRecipe):
                 ),
             )
 
+        # Create the enhanced forecast source, if it does not exist.
+        if ENHANCED_FORECAST_ID in source_connector_nodes_by_connector_id:
+            enhanced_forecast_source = source_connector_nodes_by_connector_id[ENHANCED_FORECAST_ID]
+        else:
             enhanced_forecast_fields = [
                 field_triple.enhanced_forecast_field for field_triple in _FIELD_MAPPINGS.values()
             ]
@@ -173,12 +196,6 @@ class TheWeatherCompany(TimeSeriesRecipe):
                 ),
             )
 
-            _SOURCE_CACHE[source_cache_key] = _SourceCache(
-                cleaned_observations_source=cleaned_observations_source,
-                historical_hourly_conditions_source=historical_hourly_conditions_source,
-                enhanced_forecast_source=enhanced_forecast_source,
-            )
-
         # Create the intermediate time series.
         if self._create_intermediate_time_series:
             co_time_series = TimeSeries.create(
@@ -192,7 +209,7 @@ class TheWeatherCompany(TimeSeriesRecipe):
             TimeSeriesLayer.create(
                 project=project,
                 time_series=co_time_series,
-                node=_SOURCE_CACHE[source_cache_key].cleaned_observations_source,
+                node=cleaned_observations_source,
                 order=0,
                 output_index=0,
                 label_indexer=_FIELD_MAPPINGS[self._field].cleaned_observations_field,
@@ -209,7 +226,7 @@ class TheWeatherCompany(TimeSeriesRecipe):
             TimeSeriesLayer.create(
                 project=project,
                 time_series=hhc_time_series,
-                node=_SOURCE_CACHE[source_cache_key].historical_hourly_conditions_source,
+                node=historical_hourly_conditions_source,
                 order=0,
                 output_index=0,
                 label_indexer=_FIELD_MAPPINGS[self._field].historical_hourly_conditions_field,
@@ -226,7 +243,7 @@ class TheWeatherCompany(TimeSeriesRecipe):
             TimeSeriesLayer.create(
                 project=project,
                 time_series=ef_time_series,
-                node=_SOURCE_CACHE[source_cache_key].enhanced_forecast_source,
+                node=enhanced_forecast_source,
                 order=0,
                 output_index=0,
                 label_indexer=_FIELD_MAPPINGS[self._field].enhanced_forecast_field,
@@ -240,9 +257,9 @@ class TheWeatherCompany(TimeSeriesRecipe):
             hhc_label_indexer = None
             ef_label_indexer = None
         else:
-            co_upstream_node = _SOURCE_CACHE[source_cache_key].cleaned_observations_source
-            hhc_upstream_node = _SOURCE_CACHE[source_cache_key].historical_hourly_conditions_source
-            ef_upstream_node = _SOURCE_CACHE[source_cache_key].enhanced_forecast_source
+            co_upstream_node = cleaned_observations_source
+            hhc_upstream_node = historical_hourly_conditions_source
+            ef_upstream_node = enhanced_forecast_source
 
             co_label_indexer = _FIELD_MAPPINGS[self._field].cleaned_observations_field
             hhc_label_indexer = _FIELD_MAPPINGS[self._field].historical_hourly_conditions_field
