@@ -106,7 +106,7 @@ class HPO(Resource):
     predict_end_timing: TimeRangeBoundary
     predict_reference_timing: CronTiming
     search_algorithm: Hyperopt
-    search_space: Dict[str, Optional[Union[Uniform, QUniform, LogUniform, QLogUniform]]]
+    search_space: Dict[str, Union[Uniform, QUniform, LogUniform, QLogUniform]]
 
     @classmethod
     def create(
@@ -206,7 +206,7 @@ class HPO(Resource):
         """Lists all HPOs associated with this project."""
         hpos = list_hpos.request_sync(client=get_client(), project_uuid=str(get_resource_uuid(project)))
 
-        return [HPO.parse_obj(hpo) for hpo in hpos.data]
+        return [HPO.parse_obj(hpo.dict()) for hpo in hpos.data]
 
     @property
     def state(self) -> HPOJobState:
