@@ -1,8 +1,6 @@
 from typing import Optional
 from uuid import UUID
 
-import pydantic
-
 from myst.core.time.time import Time
 from myst.models.base_model import BaseModel
 
@@ -20,9 +18,6 @@ class Resource(BaseModel):
     create_time: Time
     update_time: Optional[Time] = None
 
-    class Config:
-        extra = pydantic.Extra.ignore
-
 
 class ShareableResource(Resource):
     """A resource associated with an owner, organization, and creator.
